# ZapURL
The ZapURL package allows you to shorten your links directly through Python.

# Usage
Here is how you can shorten your URL.

```python
Zapurl.short([PUT_YOUR_URL_HERE]) # Shorten a URL with random directory
```
```python
Zapurl.custom(url, email, name, custom_directory) # Create custom URLs
```
```python
Zapurl.about() # Returns ZapURL build info
```
```python
Zapurl.site() # Gives you the official ZapURL site.
```
```python
Zapurl.latest() # Returns the latest version of ZapURL, download size, how to install it, and other information.
```
```python
Zapurl.update() # Updates your module automatically for you
```

# Upcoming
More features will be coming soon. 
- Error Reporting
- Site information
